@@ -19,7 +19,7 @@
 /* get_many considarations:
  * Avoid using get_many() on the consumer side and using put() on the producer.
  * The get_many() thread is notified on every single put(), however immediatly
- * goes to sleep again because the Queue is not big enought. Hence a lot of
+ * goes to sleep again because the Queue is not big enough. Hence a lot of
  * context switches for nothing. So it is recommended to use get_many() and
  * put_many() together with the same size of items.
  */
@@ -30,7 +30,7 @@
     catch (std::exception &e) { \
         PyErr_Format(PyExc_Exception, error_txt1, e.what()); return ret_val;} \
     catch (...) { \
-        PyErr_Format(PyExc_Exception, error_txt1, "unkown error"); return ret_val;}
+        PyErr_Format(PyExc_Exception, error_txt1, "unknown error"); return ret_val;}
 
 /* Helper class to get or release the GIL in a exception safe manner */
 class AllowThreads {
@@ -95,7 +95,7 @@ Queue_init(Queue *self, PyObject *args, PyObject *kwargs)
 
     BEGIN_SAFE_CALL
         self->bridge = new Bridge();
-    END_SAFE_CALL("Error Creating underlying queue: %s", -1)
+    END_SAFE_CALL("Error creating underlying queue: %s", -1)
     return 0;
 }
 
@@ -203,7 +203,7 @@ _wait_for_free_slots(
         bool block,
         double timeout,
         boost::mutex::scoped_lock& lock,
-        Py_ssize_t nb_of_items)
+        size_t nb_of_items)
 {
     boost::uint64_t timeout_millis = static_cast<boost::uint64_t>(timeout*1000);
 
@@ -335,10 +335,10 @@ Queue_put_many(Queue *self, PyObject *args, PyObject *kwargs)
                 items_len);
     }
 
-    if (self->maxsize > 0 and items_len > self->maxsize) {
+    if (self->maxsize > 0 and static_cast<size_t>(items_len) > self->maxsize) {
         return PyErr_Format(
                     PyExc_ValueError,
-                    "items of size %i is bigger then maxsize: %i",
+                    "items of size %i is bigger than maxsize: %i",
                     items_len,
                     self->maxsize);
     }
@@ -350,7 +350,7 @@ Queue_put_many(Queue *self, PyObject *args, PyObject *kwargs)
         _wait_for_lock(lock);
     }
 
-    if (not _wait_for_free_slots(self, block, timeout, lock, items_len)) {
+    if (not _wait_for_free_slots(self, block, timeout, lock, static_cast<size_t>(items_len))) {
         return NULL;
     }
 
@@ -358,7 +358,7 @@ Queue_put_many(Queue *self, PyObject *args, PyObject *kwargs)
         return NULL;
     }
 
-    while (itertor_item = PyIter_Next(iterator)) {
+    while ((itertor_item = PyIter_Next(iterator))) {
         self->bridge->queue.push_back(itertor_item);
         self->unfinished_tasks += 1;
 
@@ -401,7 +401,7 @@ _wait_for_items(
 {
     boost::uint64_t timeout_millis = static_cast<boost::uint64_t>(timeout*1000);
 
-    if (self->bridge->queue.size() >= items_len) {
+    if (self->bridge->queue.size() >= static_cast<size_t>(items_len)) {
         /* Fall through the end of method */
     }
     else if (not block) {
@@ -411,7 +411,7 @@ _wait_for_items(
     else if (timeout > 0) {
         boost::system_time abs_timeout = boost::get_system_time();
         abs_timeout += boost::posix_time::milliseconds(timeout_millis);
-        while (not self->bridge->queue.size() >= items_len) {
+        while (self->bridge->queue.size() < items_len) {
             if (not _timed_wait_empty(self->bridge, lock, abs_timeout)) {
                 PyErr_Format(EmptyError, "Queue Empty");
                 return false;
@@ -419,7 +419,7 @@ _wait_for_items(
         }
     }
     else {
-        while (not (self->bridge->queue.size() >= items_len)) {
+        while (not (self->bridge->queue.size() >= static_cast<size_t>(items_len))) {
             _blocked_wait_empty(self->bridge, lock);
         }
     }
@@ -515,7 +515,7 @@ Queue_get_many(Queue *self, PyObject *args, PyObject *kwargs)
     }
 
 
-    if (self->maxsize > 0 and items > self->maxsize) {
+    if (self->maxsize > 0 and static_cast<size_t>(items) > self->maxsize) {
         return PyErr_Format(
                 PyExc_ValueError,
                 "you want to get %ld but maxsize is %i",
@@ -523,10 +523,6 @@ Queue_get_many(Queue *self, PyObject *args, PyObject *kwargs)
                 self->maxsize);
     }
 
-    if ((result_tuple = PyTuple_New(items)) == NULL) {
-        return NULL;
-    }
-
     BEGIN_SAFE_CALL
 
     boost::mutex::scoped_lock lock(self->bridge->mutex, boost::try_to_lock);
@@ -538,9 +534,12 @@ Queue_get_many(Queue *self, PyObject *args, PyObject *kwargs)
         return NULL;
     }
 
+    if ((result_tuple = PyTuple_New(items)) == NULL) {
+        return NULL;
+    }
+
     for (long int i=0; i<items; i++) {
         PyObject *item = self->bridge->queue.front();
-        Py_INCREF(item);
         PyTuple_SET_ITEM(result_tuple, i, item);
 
         self->bridge->queue.pop_front();
@@ -612,7 +611,7 @@ Queue_task_done(Queue *self)
         self->bridge->all_tasks_done_cond.notify_all();
     }
 
-    END_SAFE_CALL("Error in task done: %s", NULL)
+    END_SAFE_CALL("Error in task_done: %s", NULL)
     Py_RETURN_NONE;
 }
 
